@@ -1,6 +1,9 @@
 #' @keywords internal
 "_PACKAGE"
 
+the <- rlang::new_environment()
+the$session_cache <- rlang::new_environment()
+
 ## usethis namespace: start
 #' @importFrom rlang is_empty
 #' @importFrom rlang %||%
